@@ -5,18 +5,18 @@ function phptemplate_settings($saved_settings) {
   $settings = theme_get_settings('newsflash');
 
   $defaults = array(
-    'newsflash_style' => 0,
+    'newsflash_style' => 'blue',
     'newsflash_width' => 0,
-	'newsflash_fixedwidth' => '850',
+    'newsflash_fixedwidth' => '850',
     'newsflash_breadcrumb' => 0,
-	'newsflash_iepngfix' => 0,
+    'newsflash_iepngfix' => 0,
     'newsflash_themelogo' => 0,
     'newsflash_fontfamily' => 0,
     'newsflash_customfont' => '',
     'newsflash_uselocalcontent' => 0,
     'newsflash_localcontentfile' => '',
-    'newsflash_leftsidebarwidth' => '210',
-    'newsflash_rightsidebarwidth' => '210',
+    'newsflash_leftsidebarwidth' => '25',
+    'newsflash_rightsidebarwidth' => '25',
     'newsflash_suckerfish' => 0,
     'newsflash_usecustomlogosize' => 0,
     'newsflash_logowidth' => '100',
@@ -30,9 +30,13 @@ function phptemplate_settings($saved_settings) {
     '#title' => t('Style'),
     '#default_value' => $settings['newsflash_style'],
     '#options' => array(
-      'blue' => t('Blue'),
       'copper' => t('Copper'),
       'green' => t('Green'),
+      'blue' => t('Blue'),
+      'black' => t('Black'),
+      'red' => t('Red'),
+      'violet' => t('Violet'),
+      'aqua' => t('Aqua'),
     ),
   );
 
@@ -67,20 +71,20 @@ function phptemplate_settings($saved_settings) {
     '#title' => t('Use IE PNG Fix'),
     '#default_value' => $settings['newsflash_iepngfix'],
   );
-
+  
   $form['newsflash_fontfamily'] = array(
     '#type' => 'select',
     '#title' => t('Font Family'),
     '#default_value' => $settings['newsflash_fontfamily'],
     '#options' => array(
-     'Arial, Verdana, sans-serif' => t('Arial, Verdana, sans-serif'),
-     '"Arial Narrow", Arial, Helvetica, sans-serif' => t('"Arial Narrow", Arial, Helvetica, sans-serif'),
-     '"Times New Roman", Times, serif' => t('"Times New Roman", Times, serif'),
-     '"Lucida Sans", Verdana, Arial, sans-serif' => t('"Lucida Sans", Verdana, Arial, sans-serif'),
-     '"Lucida Grande", Verdana, sans-serif' => t('"Lucida Grande", Verdana, sans-serif'),
-     'Tahoma, Verdana, Arial, Helvetica, sans-serif' => t('Tahoma, Verdana, Arial, Helvetica, sans-serif'),
-     'Georgia, "Times New Roman", Times, serif' => t('Georgia, "Times New Roman", Times, serif'),
-     'Custom' => t('Custom (specify below)'),
+       'Arial, Verdana, sans-serif' => t('Arial, Verdana, sans-serif'),
+       '"Arial Narrow", Arial, Helvetica, sans-serif' => t('"Arial Narrow", Arial, Helvetica, sans-serif'),
+       '"Times New Roman", Times, serif' => t('"Times New Roman", Times, serif'),
+       '"Lucida Sans", Verdana, Arial, sans-serif' => t('"Lucida Sans", Verdana, Arial, sans-serif'),
+       '"Lucida Grande", Verdana, sans-serif' => t('"Lucida Grande", Verdana, sans-serif'),
+       'Tahoma, Verdana, Arial, Helvetica, sans-serif' => t('Tahoma, Verdana, Arial, Helvetica, sans-serif'),
+       'Georgia, "Times New Roman", Times, serif' => t('Georgia, "Times New Roman", Times, serif'),
+       'Custom' => t('Custom (specify below)'),
     ),
   );
 
@@ -152,3 +156,5 @@ function phptemplate_settings($saved_settings) {
 
   return $form;
 }
+
+
